@@ -15,7 +15,7 @@ except ImportError:
     from md5 import md5
 
 
-class FSDBM:
+class FSDBM(object):
     '''
         >>> db = FSDBM('var/test.fdb')
         >>> db.clear()
@@ -150,7 +150,7 @@ class FSDBM:
             f.close()
 
 
-class FSDBMLight:
+class FSDBMLight(object):
     '''
     Only byte string key and value. Max key length = 190 bytes. 
         >>> db = FSDBMLight('var/test.fdb')
@@ -164,22 +164,24 @@ class FSDBMLight:
         >>> del db['a']
         >>> db.keys()
         ['b']
+        >>> db.clear()
+        >>> len(db)
+        0
     '''
     def __init__(self, db_dir, depth=1):
         self.db_dir = db_dir
         self.depth = depth
         
-    def dir(self, k):
-        '''File directory by key'''
+    def fn(self, k):
+        '''Full file path by key'''
+        if isinstance(k, unicode):
+            k = k.encode('utf-8')
         hash = md5(k).hexdigest()
         dirs = [self.db_dir]
         for i in xrange(-1 - self.depth * 2, -1, 2):
             dirs.append(hash[i:i+2])
-        return os.path.join(*dirs)
-        
-    def fn(self, k):
-        '''Full file path by key'''
-        return os.path.join(self.dir(k), base64.urlsafe_b64encode(k))
+        dir = os.path.join(*dirs)
+        return os.path.join(dir, base64.urlsafe_b64encode(k))
 
     def __getitem__(self, k):
         try:
@@ -188,14 +190,15 @@ class FSDBMLight:
             raise KeyError
 
     def __setitem__(self, k, v):
+        fn = self.fn(k)
         try:
-            f = open(self.fn(k), 'w')
+            f = open(fn, 'w')
         except IOError:
             try:
-                os.makedirs(self.dir(k))
+                os.makedirs(os.path.dirname(fn))
             except OSError:
                 pass
-            f = open(self.fn(k), 'w')
+            f = open(fn, 'w')
         f.write(v)
         f.close()
 
@@ -215,7 +218,7 @@ class FSDBMLight:
 
     def get(self, k, default=None):
         try:
-            return self.__getitem__(k)
+            return self[k]
         except KeyError:
             return default
 
@@ -248,6 +251,41 @@ class FSDBMLight:
         return list(self.iteritems())
 
 
+class FSDBMLightUnicode(FSDBMLight):
+    '''
+    Only unicode key and value. Max key length = 190 bytes. 
+        >>> db = FSDBMLightUnicode('var/test.fdb')
+        >>> db.clear()
+        >>> db[u'a'] = u'bbb'
+        >>> db[u'a'] == u'bbb'
+        True
+        >>> db[u'b'] = u'1'
+        >>> len(db)
+        2
+        >>> del db[u'a']
+        >>> db.keys()
+        [u'b']
+        >>> db.clear()
+        >>> len(db)
+        0
+    '''
+    def fn(self, k):
+        '''Full file path by key'''
+        return super(self.__class__, self).fn(k.encode('utf-8'))
+        
+    def __getitem__(self, k):
+        try:
+            return open(self.fn(k)).read().decode('utf-8')
+        except IOError:
+            raise KeyError
+
+    def __setitem__(self, k, v):
+        super(self.__class__, self).__setitem__(k, v.decode('utf-8'))
+        
+    def iterkeys(self):
+        for k in super(self.__class__, self).iterkeys():
+            yield k.decode('utf-8')
+
 
 def recomended_depth(row_cnt, max_in_dir=5000):
     '''
